<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

/**
*
* Gets product price
*
* @param WC_Product or WC_Product_Variation $product - The product or variation object
* @param WC_Product - $child - The product child (for grouped or bundled products)
* @param bool - $display - True if displaying the price on the front end
* @param str - $type - 'single' or 'array', 'single' will return the price, 'array' an array of regular and sale price if on sale
* @return str or array - $prices
*
**/
function wceb_get_product_price( $product, $child = false, $display = false, $type = 'single' ) {

	$prices_include_tax = get_option( 'woocommerce_prices_include_tax' );
	$tax_display_mode   = get_option( 'woocommerce_tax_display_shop' );

	if ( $child ) {
    	$_product = $child;
    } else {
    	$_product = $product;
    }

    if ( $product->is_type( 'bundle' ) && $child ) {

        if ( is_callable( array( $child, 'get_id' ) ) ) {
            $id = $child->get_id();
        } else {
            $id = isset( $child->variation_id ) ? $child->variation_id : $child->id;
        }

    	$bundled_items = $product->get_bundled_items();

        $ids = array();
        foreach ( $bundled_items as $bundled_item ) {

            if ( $bundled_item->get_product_variations() ) {

                foreach ( $bundled_item->get_product_variations() as $variation ) {
                    
                    if ( $variation['variation_id'] == $id ) {

                        if ( $bundled_item->is_priced_individually() ) {
                            $discount = $bundled_item->get_discount();
                        } else {
                            return false;
                        }
                        
                    }

                }

            } else {

                if ( $bundled_item->product_id == $id ) {

                    if ( $bundled_item->is_priced_individually() ) {
                        $discount = $bundled_item->get_discount();
                    } else {
                        return false;
                    }
                    
                }

            }

        }

        $regular_price = $child->get_regular_price();
		$price = $child->get_price();

        if ( isset( $discount ) && ! empty( $discount ) ) {
            $price -= ( $price * $discount / 100 );
        }

    } else {

		$regular_price = $_product->get_regular_price();
		$price = $_product->get_price();

	}

	if ( $type === 'array' ) {

		$prices = array( 'price' => '', 'regular_price' => '' );

		if ( true === $display ) {

            $args = array( 'price' => $price );

            if ( $tax_display_mode === 'incl' ) {
                $prices['price'] = function_exists( 'wc_get_price_including_tax' ) ? wc_get_price_including_tax( $_product, $args ) : $_product->get_price_including_tax( 1, $price );
            } else {
                $prices['price'] = function_exists( 'wc_get_price_excluding_tax' ) ? wc_get_price_excluding_tax( $_product, $args ) : $_product->get_price_excluding_tax( 1, $price );
            }

	    } else {

            $args = array( 'price' => $price );

            if ( $prices_include_tax === 'yes' ) {
                $prices['price'] = function_exists( 'wc_get_price_including_tax' ) ? wc_get_price_including_tax( $_product, $args ) : $_product->get_price_including_tax( 1, $price );
            } else {
                $prices['price'] = function_exists( 'wc_get_price_excluding_tax' ) ? wc_get_price_excluding_tax( $_product, $args ) : $_product->get_price_excluding_tax( 1, $price );
            }

	    }

		if ( true === $display ) {

            $args = array( 'price' => $regular_price );

            if ( $tax_display_mode === 'incl' ) {
                $prices['regular_price'] = function_exists( 'wc_get_price_including_tax' ) ? wc_get_price_including_tax( $_product, $args ) : $_product->get_price_including_tax( 1, $regular_price );
            } else {
                $prices['regular_price'] = function_exists( 'wc_get_price_excluding_tax' ) ? wc_get_price_excluding_tax( $_product, $args ) : $_product->get_price_excluding_tax( 1, $regular_price );
            }

	    } else {

            $args = array( 'price' => $regular_price );

            if ( $prices_include_tax === 'yes' ) {
                $prices['regular_price'] = function_exists( 'wc_get_price_including_tax' ) ? wc_get_price_including_tax( $_product, $args ) : $_product->get_price_including_tax( 1, $regular_price );
            } else {
                $prices['regular_price'] = function_exists( 'wc_get_price_excluding_tax' ) ? wc_get_price_excluding_tax( $_product, $args ) : $_product->get_price_excluding_tax( 1, $regular_price );
            }

	    }

		return $prices;

	} else {

		if ( true === $display ) {

            $args = array( 'price' => $price );

            if ( $tax_display_mode === 'incl' ) {
                return function_exists( 'wc_get_price_including_tax' ) ? wc_get_price_including_tax( $_product, $args ) : $_product->get_price_including_tax( 1, $price );
            } else {
                return function_exists( 'wc_get_price_excluding_tax' ) ? wc_get_price_excluding_tax( $_product, $args ) : $_product->get_price_excluding_tax( 1, $price );
            }

	    }

        $args = array( 'price' => $price );

        if ( $prices_include_tax === 'yes' ) {
            return function_exists( 'wc_get_price_including_tax' ) ? wc_get_price_including_tax( $_product, $args ) : $_product->get_price_including_tax( 1, $price );
        } else {
            return function_exists( 'wc_get_price_excluding_tax' ) ? wc_get_price_excluding_tax( $_product, $args ) : $_product->get_price_excluding_tax( 1, $price );
        }

	}

}

function wceb_get_product_children_ids( $product ) {

	$product_children = array();

    if ( $product->is_type('grouped') ) {
        $product_children = $product->get_children();  
    } else if ( $product->is_type('bundle') ) {

        $bundled = $product->get_bundled_item_ids();
        $product_children = array();

        if ( $bundled ) foreach ( $bundled as $bundled_item_id ) {

            $bundled_item = $product->get_bundled_item( $bundled_item_id );
            $_product = $bundled_item->product;
            
            if ( $_product->is_type( 'variable' ) ) {
                $variations = $_product->get_children();

                foreach ( $variations as $variation_id ) {
                    $product_children[] = $variation_id;
                }
            }

            $product_children[] = is_callable( array( $_product, 'get_id' ) ) ? $_product->get_id() : $_product->id;

        }

        // Add main bundle product
        $product_children[] = is_callable( array( $product, 'get_id' ) ) ? $product->get_id() : $product->id;

    }

    return $product_children;

}